Mortality Module
================

The mortality module provides tools for working with mortality tables and survival functions.

.. automodule:: actuneo.mortality
   :members:
   :undoc-members:
   :show-inheritance:

MortalityTable
--------------

.. autoclass:: actuneo.mortality.MortalityTable
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__

SurvivalFunctions
-----------------

.. autoclass:: actuneo.mortality.SurvivalFunctions
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__

